@@ -7,7 +7,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -27,7 +27,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -179,6 +179,7 @@ public class Rule2JSON2Rule extends AbstractObject2JSON2Object<Rule> {
         DAYS("days",":days"),
         ADDRESSES("addresses",":addresses"),
         SUBJECT("subject",":subject"),
+        FROM("from", ":from"),
         TEXT("text",null);
 
         private final String fieldname;
