@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,7 +53,7 @@ import java.util.HashMap;
 import java.util.Map;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.Reloadable;
-import com.openexchange.mailfilter.osgi.Activator;
+import com.openexchange.mailfilter.osgi.MailFilterActivator;
 
 /**
  * {@link MailFilterReloadable}
@@ -83,7 +83,7 @@ public class MailFilterReloadable implements Reloadable {
     @Override
     public void reloadConfiguration(ConfigurationService configService) {
         try {
-            Activator.checkConfigfile();
+            MailFilterActivator.checkConfigfile();
         } catch (Exception e) {
             LOG.error("Error reloading configuration for bundle com.openexchange.mail.filter: {}", e);
         }
